div.pq-select-menu > .pq-select-option-label{
    float: none;
    text-align: left;
    margin-right: 0px;
    padding-top: 0px;
}

.pq-select-all{
    float: none;
    text-align: left;
    margin-right: 0px;
    padding-top: 0px;
}

.ui-state-default, .ui-widget-content .ui-state-default, .ui-widget-header .ui-state-default {
    text-shadow: 0px 0px 0px;
}
